@@ -1,4 +1,4 @@
-version = "0.3.1"
+version = "0.4.0"
 language = "en-US"
 timeout = 15
 user = None
@@ -47,9 +47,18 @@ from .issuingbalance.__issuingbalance import IssuingBalance
 from . import creditnote
 from .creditnote.__creditnote import CreditNote
 
+from . import creditsigner
+from .creditsigner.__creditsigner import CreditSigner
+
 from . import creditpreview
 from .creditpreview.__creditpreview import CreditPreview
 
+from . import individualidentity
+from .individualidentity.__individualidentity import IndividualIdentity
+
+from . import individualdocument
+from .individualdocument.__individualdocument import IndividualDocument
+
 from . import dynamicbrcode
 from .dynamicbrcode.__dynamicbrcode import DynamicBrcode
 
